Skip to contents

Displays a compact summary of a parsed data source, including source metadata and a preview of the data.

Usage

# S3 method for class 'molpath_parsed'
print(x, ...)

Arguments

x

A molpath_parsed object.

...

Additional arguments (ignored).

Value

The molpath_parsed object (invisibly).